from typing import TypedDict, Dict, Any


class BasicAuth(TypedDict):
    """
Contains HTTP basic auth parameters to the following request types:

  - [get](../http_requests.json/#get)
  - [post](../http_requests.json/#post)
  - [patch](../http_requests.json/#patch)
  - [delete](../http_requests.json/#delete)

!!! info "All BasicAuth Keys"

    __username__: The basic authentication username.

    __password__: The basic authentication password.
    """

    username: str
    password: str


class JsonResponse(TypedDict):
    """
Contains HTTP response data from the following request types:

  - [get](../http_requests.json/#get)
  - [post](../http_requests.json/#post)
  - [patch](../http_requests.json/#patch)
  - [delete](../http_requests.json/#delete)


!!! info "All JsonResponse Keys"

    __status_code__: The response status code as an integer.

    __headers__: A dictionary containing the response headers.

    __cookies__: A dictionary containing the response cookies.

    __json__: The JSON response to the request.
    """

    status_code: int
    headers: Dict[str, str]
    cookies: Dict[str, str]
    json: Any
